"use strict";
Object.defineProperty(exports, "__esModule", { value: true });
exports.S3ComplianceChecker = void 0;
const aws_s3_1 = require("@aws-cdk/aws-s3");
const core_1 = require("@aws-cdk/core");
const compliance_checker_1 = require("./compliance-checker");
class S3ComplianceChecker extends compliance_checker_1.BaseComplianceChecker {
    constructor(config) {
        super({ s3: config });
    }
    checkCompliance(node) {
        var _a, _b;
        if ((_a = this.config.s3) === null || _a === void 0 ? void 0 : _a.serverSideEncryption) {
            this.checkServerSideEncryption(node);
        }
        else if ((_b = this.config.s3) === null || _b === void 0 ? void 0 : _b.ssl) {
            this.checkSSL(node);
        }
    }
    /**
     * [S3.4] S3 buckets should have server-side encryption enabled
     * Ref: https://docs.aws.amazon.com/securityhub/latest/userguide/securityhub-standards-fsbp-controls.html#fsbp-s3-4
     */
    checkServerSideEncryption(node) {
        if (node instanceof aws_s3_1.CfnBucket) {
            if (!node.hasOwnProperty("bucketEncryption") ||
                node.bucketEncryption === undefined ||
                (0, core_1.isResolvableObject)(node.bucketEncryption)) {
                core_1.Annotations.of(node).addError("[S3.4] S3 buckets should have server-side encryption enabled");
            }
            else if (node.bucketEncryption.serverSideEncryptionConfiguration === undefined ||
                (0, core_1.isResolvableObject)(node.bucketEncryption.serverSideEncryptionConfiguration) ||
                node.bucketEncryption.serverSideEncryptionConfiguration.length === 0 ||
                (0, core_1.isResolvableObject)(node.bucketEncryption.serverSideEncryptionConfiguration[0])) {
                core_1.Annotations.of(node).addError("[S3.4] S3 buckets should have server-side encryption enabled.2");
            }
            else {
                const ssec = node.bucketEncryption.serverSideEncryptionConfiguration[0];
                if ((0, core_1.isResolvableObject)(ssec.bucketKeyEnabled) ||
                    ssec.bucketKeyEnabled === false) {
                    core_1.Annotations.of(node).addError("[S3.4] S3 buckets should have server-side encryption enabled.3");
                }
                else if (ssec.serverSideEncryptionByDefault === undefined ||
                    (0, core_1.isResolvableObject)(ssec.serverSideEncryptionByDefault) ||
                    !["AES-256", "aws:kms"].includes(ssec.serverSideEncryptionByDefault.sseAlgorithm)) {
                    core_1.Annotations.of(node).addError("[S3.4] S3 buckets should have server-side encryption enabled.4");
                }
            }
        }
    }
    /**
     * [S3.5] S3 buckets should require requests to use Secure Socket Layer
     * Ref: https://docs.aws.amazon.com/securityhub/latest/userguide/securityhub-standards-fsbp-controls.html#fsbp-s3-5
     */
    checkSSL(node) {
        var _a, _b;
        if (node instanceof aws_s3_1.CfnBucketPolicy) {
            if (((_b = (_a = node.policyDocument) === null || _a === void 0 ? void 0 : _a.Statement) === null || _b === void 0 ? void 0 : _b.length) === 0) {
                core_1.Annotations.of(node).addError("[S3.5] S3 buckets should require requests to use Secure Socket Layer");
            }
        }
    }
}
exports.S3ComplianceChecker = S3ComplianceChecker;
